##
# Copyright (c) 2009-2015 Apple Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
##

from txweb2.http_headers import DefaultHTTPHandler, tokenize, generateList, singleHeader

DefaultHTTPHandler.updateParsers({
    "x-forwarded-for": (tokenize, list),
    "x-forwarded-host": (tokenize, list),
    "x-forwarded-server": (tokenize, list),
})
DefaultHTTPHandler.updateGenerators({
    "x-forwarded-for": (generateList, singleHeader),
    "x-forwarded-host": (generateList, singleHeader),
    "x-forwarded-server": (generateList, singleHeader),
})
